;*****************************************************************************
;  Batch file which creates a .sav file containing various general parameters
;  associated with NPP data.
;
;  Output:
;  1) general.VisNIR.sav
;  2) general.SMWIR.sav
;  3) general.LWIR.sav
;  4) general.RSB.sav
;  5) general.TEB.sav
;  
;  v1 - 12/21/2007 - Jeff McIntire
;*****************************************************************************

PRO general_data_2

nham=2
maxgain=2
maxsubsets=2
maxdet=32

; DNB bands.
nbands=4

; VisNIR bands.
nbands=9
band_name=['I1','I2','M1','M2','M3','M4','M5','M6','M7']
band_type=[1,1,0,0,0,0,0,0,0]                                                                    ; I bands = 1 and M bands = 0.
gain_type=[0,0,1,1,1,1,1,0,1]					                                 ; Single gain = 0 and dual gain = 1.
detectors=[32,32,16,16,16,16,16,16,16]
subsets=[2,2,1,1,1,1,1,1,1]					                                 ; Number of subsets.
L_max=[[718.,349.,135.,127.,107.,78.,59.,41.,29.],[0.,0.,615.,687.,702.,667.,651.,0.,349.]]
L_min=[[5.,10.3,30.,26.,22.,12.,8.6,5.3,3.4],[0.,0.,135.,127.,107.,78.,59.,0.,29.]]
L_typ=[[22.,25.,44.9,40.,32.,21.,10.,9.6,6.4],[0.,0.,155.,146.,123.,90.,68.,0.,33.4]]
lambda_center=[0.640,0.865,0.412,0.445,0.488,0.555,0.672,0.746,0.865]	                                 ; Center wavelengths.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands,band_name,band_type,gain_type,detectors,subsets,L_max,L_typ,L_min,lambda_center, $
  filename='/home/jmcintire/VIIRS_Data/general.VisNIR.2.sav'

; SMWIR bands.
nbands=8
band_name=['I3','I4','M10','M11','M12','M13','M8','M9']
band_type=[1,1,0,0,0,0,0,0]					                                 ; I bands = 1 and M bands = 0.
gain_type=[0,0,0,0,0,1,0,0]					                                 ; Single gain = 0 and dual gain = 1.
detectors=[32,32,16,16,16,16,16,16]
subsets=[2,2,1,1,1,1,1,1]						                         ; Number of subsets.
L_max=[[72.5,3.01,71.2,31.8,2.82,3.47,164.9,77.1],[0,0,0,0,0,404.33,0,0]]
L_min=[[1.2,0.00180,1.2,0.12,0.0214,0.371,3.5,0.6],[0,0,0,0,0,3.47,0,0]]
L_typ=[[7.3,0.11,7.3,0.12,0.1,0.79,5.4,6.],[0,0,0,9.53,0,0,0,0]]
lambda_center=[1.610,3.740,1.610,2.250,3.700,4.050,1.240,1.378]		                         ; Center wavelengths.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands,band_name,band_type,gain_type,detectors,subsets,L_max,L_typ,L_min,lambda_center, $
  filename='/home/jmcintire/VIIRS_Data/general.SMWIR.2.sav'

; LWIR bands.
nbands=5
band_name=['I5','M14','M15','M16A','M16B']
band_type=[1,0,0,0,0]						                                 ; I bands = 1 and M bands = 0.
gain_type=[0,0,0,0,0]						                                 ; Single gain = 0 and dual gain = 1.
detectors=[32,16,16,16,16]
subsets=[2,1,1,1,1]						                                 ; Number of subsets.
L_max=[15.41,17.54,17.08,14.48,14.48]
L_min=[0.813,0.371,0.726,0.873,0.873]
L_typ=[1.53,5.14,9.7,8.97,8.97]
T_max=[340.,336.,343.,340.,340.]
T_min=[190.,190.,190.,190.,190.]
T_typ=[210.,270.,300.,300.,300.]
lambda_center=[11.450,8.550,10.763,12.013,12.013]			         	          ; Center wavelengths.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands,band_name,band_type,gain_type,detectors,subsets,L_max,L_min,L_typ,T_max,T_min,T_typ,lambda_center, $
  filename='/home/jmcintire/VIIRS_Data/general.LWIR.2.sav'

; RSB bands.
nbands=14
band_name=['I1','I2','I3','M1','M10','M11','M2','M3','M4','M5','M6','M7','M8','M9']
band_type=[1,1,1,0,0,0,0,0,0,0,0,0,0,0]				                                 ; I bands = 1 and M bands = 0.
gain_type=[0,0,0,1,0,0,1,1,1,1,0,1,0,0]				                                 ; Single gain = 0 and dual gain = 1.
detectors=[32,32,32,16,16,16,16,16,16,16,16,16,16,16]
subsets=[2,2,2,1,1,1,1,1,1,1,1,1,1,1]                                                            ; Number of subsets.
L_max=[[718.,349.,72.5,135.,71.2,31.8,127.,107.,78.,59.,41.,29.,164.9,77.1],[0.,0.,0.,615.,0.,0.,687.,702.,667.,651.,0.,349.,0.,0.]]
L_min=[[5.,10.3,30.,1.2,26.,1.2,0.12,22.,12.,8.6,5.3,3.4,3.5,0.6],[0.,0.,0.,135.,0.,0.,127.,107.,78.,59.,0.,29.,0.,0.]]
L_typ=[[22.,25.,7.3,44.9,7.3,0.12,40.,32.,21.,10.,9.6,6.4,5.4,6.],[0.,0.,0.,155.,0.,0.,146.,123.,90.,68.,0.,33.4,0.,0.]]
lambda_center=[0.640,0.865,1.610,0.412,1.610,2.250,0.445,0.488,0.555,0.672,0.746,0.865,1.240,1.378]	; Center wavelengths.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands,band_name,band_type,gain_type, $
	detectors,subsets,L_max,L_min,L_typ,lambda_center,filename='/home/jmcintire/VIIRS_Data/general.RSB.2.sav'

; TEB bands.
nbands=8
band_name=['I4','I5','M12','M13','M14','M15','M16A','M16B']
band_type=[1,1,0,0,0,0,0,0]						                         ; I bands = 1 and M bands = 0.
gain_type=[0,0,0,1,0,0,0,0]						                         ; Single gain = 0 and dual gain = 1.
detectors=[32,32,16,16,16,16,16,16]
subsets=[2,2,1,1,1,1,1,1]						                         ; Number of subsets.
L_max=[[3.01,15.41,2.82,3.47,17.54,17.08,14.48,14.48],[0,0,0,404.33,0,0,0,0]]
L_min=[[0.00180,0.813,0.00780,0.0214,0.371,0.726,0.873,0.873],[0,0,0,3.47,0,0,0,0]]
L_typ=[[0.11,1.53,0.1,0.79,5.14,9.7,8.97,8.97],[0,0,0,9.53,0,0,0,0]]
T_max=[[353.,340.,353.,343.,336.,343.,340.,340.],[0,0,0,634.,0,0,0,0]]
T_min=[[210.,190.,230.,230.,190.,190.,190.,190.],[0,0,0,343.,0,0,0,0]]
T_typ=[[270.,210.,270.,300.,270.,300.,300.,300.],[0,0,0,380.,0,0,0,0]]
lambda_center=[3.740,11.450,3.700,4.050,8.550,10.763,12.013,12.013]	                                 ; Center wavelengths.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands,band_name,band_type,gain_type,detectors,subsets,L_max,L_min,L_typ,T_max,T_min,T_typ,lambda_center, $
filename='/home/jmcintire/VIIRS_Data/general.TEB.2.sav'

END
